aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_crypto_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_crypto_lib.h')
-rw-r--r--src/include/taler_crypto_lib.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/taler_crypto_lib.h b/src/include/taler_crypto_lib.h
index 71ad07712..1e4a278c1 100644
--- a/src/include/taler_crypto_lib.h
+++ b/src/include/taler_crypto_lib.h
@@ -4756,7 +4756,7 @@ TALER_age_commitment_hash (
*
* @param mask The age mask the defines the age groups
* @param age The actual age for which an age commitment is generated
* @param salt The salt that goes into the key generation. MUST be choosen uniformly random.
* @param comm_proof[out] The generated age commitment, ->priv and ->pub allocated via GNUNET_malloc on success
* @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise
*/
@@ -4764,7 +4764,7 @@ enum GNUNET_GenericReturnValue
TALER_age_restriction_commit (
const struct TALER_AgeMask *mask,
const uint8_t age,
- const uint64_t salt,
+ const struct GNUNET_HashCode *seed,
struct TALER_AgeCommitmentProof *comm_proof);
@@ -4756,7 +4756,7 @@ TALER_age_commitment_hash (
* @param mask The age mask the defines the age groups
* @param age The actual age for which an age commitment is generated
- * @param salt The salt that goes into the key generation. MUST be choosen uniformly random.
+ * @param seed The seed that goes into the key generation. MUST be choosen uniformly random.
* @param comm_proof[out] The generated age commitment, ->priv and ->pub allocated via GNUNET_malloc on success
* @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise